==> unity-webapps-hulu-player_2.4.12.tar.gz: unity-webapps-hulu-player-2.4.12/hulu-player.user.js <==
// ==UserScript==
// @include       http://www.hulu.com/*
// @require       utils.js
// ==/UserScript==

evalInPageContext(function () {
     // player don't have playVideo/pauseVideo/getCurrentTime methods
     // in greasemonkey context.

    window.Unity = external.getUnityObject(1);

    function trim(str) {
	return str.replace(/^\s+|\s+$/g, "");
    }
    function extractText(element) {
        var i, result = '';

        for (i = 0; i < element.childElementCount; i++) {
            var child = element.children[i];
            if (child.textContent) {
                result += child.textContent;
            } else {
                result += extractText(child);
            }
        }
        return result;
    }

    function getTrackInfo() {
	var album = trim(document.evaluate('//div[@class="video-meta"]/h2[@class="video-titles"]/a[contains(@class,"show-link")]/span[@class="show-title"]', document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue.textContent);
	var title = trim(document.evaluate('//div[@class="video-meta"]/h2[@class="video-titles"]/span[@class="episode-title"]', document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue.textContent);
        return {
            title: title,
            album: album,
            artist: null,
            artLocation: 'http://static.huluim.com/images/logo.jpg'
        };
    }

    function getPlayerState(callback) {
        var player = document.getElementById('player');
        var time = player.getCurrentTime();
        setTimeout(function () {
            callback(player.getCurrentTime() === time);
        }, 100);
    }

    function playOrPause() {
        getPlayerState(function (isPaused) {
            var player = document.getElementById('player');
            if (isPaused) {
                player.resumeVideo();
            } else {
                player.pauseVideo();
            }
        });
    }

    function musicPlayerSetup() {
        Unity.MediaPlayer.init("Hulu");
        Unity.MediaPlayer.setCanGoPrevious(false);

        Unity.MediaPlayer.onPlayPause(function () {
            playOrPause();
        });

        Unity.MediaPlayer.onNext(function () {
            var player = document.getElementById('player');
            player.nextVideo();
        });

        setInterval(function () {
            Unity.MediaPlayer.setTrack(getTrackInfo());

            getPlayerState(function (isPaused) {
                if (!isPaused) {
                    Unity.MediaPlayer.setPlaybackState(Unity.MediaPlayer.PlaybackState.PLAYING);
                } else {
                    Unity.MediaPlayer.setPlaybackState(Unity.MediaPlayer.PlaybackState.PAUSED);
                }
            });
        }, 1000);

        Unity.MediaPlayer.setTrack(getTrackInfo());
    }

    Unity.init({ name: "Hulu",
		 domain: 'hulu.com',
		 homepage: 'http://www.hulu.com/profile/queue', //TODO: include it
		 iconUrl: "icon://unity-webapps-hulu",
                 onInit: musicPlayerSetup });
});

==> unity-webapps-hulu-player_2.4.16+13.10.20130924.2.orig.tar.gz: unity-webapps-hulu-player-2.4.16+13.10.20130924.2/hulu-player.user.js <==
// ==UserScript==
// @include       http://www.hulu.com/*
// @require       utils.js
// ==/UserScript==

// This placeholder gets munged with real data at build time.
var WebappsGettextDict = JSON.parse(unescape(
    "%7B%22GETTEXT%22%3A%22PLACEHOLDER%22%7D"
));

evalInPageContext(function () {
     // player don't have playVideo/pauseVideo/getCurrentTime methods
     // in greasemonkey context.

    window.Unity = external.getUnityObject(1);

    function trim(str) {
        return str.replace(/^\s+|\s+$/g, "");
    }
    function extractText(element) {
        var i, result = '';

        for (i = 0; i < element.childElementCount; i++) {
            var child = element.children[i];
            if (child.textContent) {
                result += child.textContent;
            } else {
                result += extractText(child);
            }
        }
        return result;
    }

    function getTrackInfo() {
        var album = trim(document.evaluate('//div[@class="video-meta"]/h2[@class="video-titles"]/a[contains(@class,"show-link")]/span[@class="show-title"]', document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue.textContent);
        var title = trim(document.evaluate('//div[@class="video-meta"]/h2[@class="video-titles"]/span[@class="episode-title"]', document, null, XPathResult.ANY_UNORDERED_NODE_TYPE, null).singleNodeValue.textContent);
        return {
            title: title,
            album: album,
            artist: null,
            artLocation: 'http://static.huluim.com/images/logo.jpg'
        };
    }

    function getPlayerState(callback) {
        var player = document.getElementById('player');
        var time = player.getCurrentTime();
        setTimeout(function () {
            callback(player.getCurrentTime() === time);
        }, 100);
    }

    function playOrPause() {
        getPlayerState(function (isPaused) {
            var player = document.getElementById('player');
            if (isPaused) {
                player.resumeVideo();
            } else {
                player.pauseVideo();
            }
        });
    }

    function musicPlayerSetup() {
        Unity.MediaPlayer.init("Hulu");
        Unity.MediaPlayer.setCanGoPrevious(false);

        Unity.MediaPlayer.onPlayPause(function () {
            playOrPause();
        });

        Unity.MediaPlayer.onNext(function () {
            var player = document.getElementById('player');
            player.nextVideo();
        });

        setInterval(function () {
            Unity.MediaPlayer.setTrack(getTrackInfo());

            getPlayerState(function (isPaused) {
                if (!isPaused) {
                    Unity.MediaPlayer.setPlaybackState(Unity.MediaPlayer.PlaybackState.PLAYING);
                } else {
                    Unity.MediaPlayer.setPlaybackState(Unity.MediaPlayer.PlaybackState.PAUSED);
                }
            });
        }, 1000);

        Unity.MediaPlayer.setTrack(getTrackInfo());
    }

    Unity.init({ name: "hulu-player",
                 domain: 'hulu.com',
                 homepage: 'http://www.hulu.com/profile/queue', //TODO: include it
                 iconUrl: "icon://unity-webapps-hulu",
                 onInit: musicPlayerSetup });
});
